@@ -12,8 +12,7 @@ import numpy as np
 import matplotlib.pyplot as plt
 
 # from ppgnss import cython_extend
-from ppgnss import gnss_io
-
+from ppgnss import gnss_io, gnss_time
 
 import xarray as xr
 import pandas as pd
@@ -909,6 +908,34 @@ class TestIO(unittest.TestCase):
                                       "MIT0OPSFIN_20242930000_01D_01D_SOL.SNX")
         
         snx_data = gnss_io.read_sinex(gnss_snx_filename)
-        print(snx_data["SOLUTION/ESTIMATE"].tail())
-        print(snx_data.keys())
+        # print(snx_data["SOLUTION/ESTIMATE"].tail())
+        # print(snx_data.keys())
+    def test_read_slr_snx_file(self):
+        slr_snx_filename = path.join(path.dirname(__file__), "data",
+                                     "ilrsa.pos+eop.180422.v170.snx")
+        snx_data = gnss_io.read_sinex(slr_snx_filename)
+        
+    def test_read_ivs_snx_file(self):
+        ivs_snx_file = path.join(path.dirname(__file__), "data",
+                                 '02JUL18XE_ivs2020a.snx')
+        snx_data = gnss_io.read_sinex(ivs_snx_file)
+        
+    
+    def test_read_disconti_file(self):
+        disconti_file = path.join(path.dirname(__file__), "data",
+                                  "ITRF2020-soln-gnss.snx")
+        data = gnss_io.read_disconti_file(disconti_file)
+        self.assertEqual(data["site_name"][0], "00NA")
+        self.assertEqual(data["site_name"][len(data)-1], "ZWEN")
+        self.assertEqual(data["end_time"][0], gnss_time.yeardoysec2time("16:302:00000"))
+        self.assertEqual(data["start_time"][len(data)-4], gnss_time.yeardoysec2time("07:164:43200"))
+        self.assertEqual(data["long_name"][0], "00NA_001")
+        
+    def test_read_SSC(self):
+        ssc_filename = path.join(path.dirname(__file__), "data", "ITRF2020_GNSS.SSC.txt")
+        df = gnss_io.read_ITRF_SSC(ssc_filename, ref_epoch=2015.0)
+        print(df.tail())
+        self.assertEqual(df["id"][0], "OPMT")
+        self.assertAlmostEqual(df["x"][4281], 2436208.0947, 4)
+        self.assertAlmostEqual(df["vx"][4281], -0.01837, 5)
         
\ No newline at end of file
